package com.googlecode.wicket.jquery.ui.dialog;

import java.io.Serializable;

import org.apache.wicket.markup.html.panel.Fragment;
import org.apache.wicket.model.IModel;
import org.apache.wicket.model.Model;

/**
 * Provides a dialog where the content is coming from a {@link Fragment}
 * 
 * @author Sebastien Briquet - sebastien@7thweb.net
 *
 * @param <T> the type of the model object
 */
public abstract class FragmentDialog<T extends Serializable> extends AbstractDialog<T>
{
	private static final long serialVersionUID = 1L;
	
	/**
	 * @param id the markupId, an html div suffice to host a dialog.
	 * @param title the title of the dialog 
	 */
	public FragmentDialog(String id, String title)
	{
		super(id, title);
		
		this.init();
	}
	
	/**
	 * @param id the markupId, an html div suffice to host a dialog.
	 * @param title the title of the dialog 
	 * @param model the model to be used in the dialog. It is retransmitted to the {@link DialogEvent} object.
	 */
	public FragmentDialog(String id, String title, Model<T> model)
	{
		super(id, title, model);
		
		this.init();
	}

	/**
	 * @param id the markupId, an html div suffice to host a dialog.
	 * @param title the title of the dialog 
	 * @param modal indicates whether the dialog is modal
	 */
	public FragmentDialog(String id, String title, boolean modal)
	{
		super(id, title, modal);
		
		this.init();
	}
	
	/**
	 * @param id markupId, an html div suffice to host a dialog.
	 * @param title the title of the dialog 
	 * @param modal indicates whether the dialog is modal
	 * @param model the model to be used in the dialog; it is retransmitted to the {@link DialogEvent} object.
	 */
	public FragmentDialog(String id, String title, IModel<T> model, boolean modal)
	{
		super(id, title, model, modal);
		
		this.init();
	}
	
	/**
	 * Initialize component
	 */
	private void init()
	{
		this.add(this.newFragment("fragment"));
	}

	/**
	 * Factory method that returns a new Fragment
	 * @param id the component id to be used for the new fragment. ie: <code>new Fragment(id, "my-fragment", MyPage.this);</code>
	 * @return the fragment
	 */
	protected abstract Fragment newFragment(String id);
}
